@@ -1,24 +1,31 @@
-"""
-Meta Data Extension for Python-Markdown
-=======================================
+# Meta Data Extension for Python-Markdown
+# =======================================
 
+# This extension adds Meta Data handling to markdown.
+
+# See https://Python-Markdown.github.io/extensions/meta_data
+# for documentation.
+
+# Original code Copyright 2007-2008 [Waylan Limberg](http://achinghead.com).
+
+# All changes Copyright 2008-2014 The Python Markdown Project
+
+# License: [BSD](https://opensource.org/licenses/bsd-license.php)
+
+"""
 This extension adds Meta Data handling to markdown.
 
-See <https://Python-Markdown.github.io/extensions/meta_data>
-for documentation.
-
-Original code Copyright 2007-2008 [Waylan Limberg](http://achinghead.com).
-
-All changes Copyright 2008-2014 The Python Markdown Project
-
-License: [BSD](https://opensource.org/licenses/bsd-license.php)
-
+See the [documentation](https://Python-Markdown.github.io/extensions/meta_data)
+for details.
 """
 
+from __future__ import annotations
+
 from . import Extension
 from ..preprocessors import Preprocessor
 import re
 import logging
+from typing import Any
 
 log = logging.getLogger('MARKDOWN')
 
@@ -38,16 +45,16 @@ class MetaExtension (Extension):
         self.md = md
         md.preprocessors.register(MetaPreprocessor(md), 'meta', 27)
 
-    def reset(self):
+    def reset(self) -> None:
         self.md.Meta = {}
 
 
 class MetaPreprocessor(Preprocessor):
     """ Get Meta-Data. """
 
-    def run(self, lines):
+    def run(self, lines: list[str]) -> list[str]:
         """ Parse Meta-Data and store in Markdown.Meta. """
-        meta = {}
+        meta: dict[str, Any] = {}
         key = None
         if lines and BEGIN_RE.match(lines[0]):
             lines.pop(0)
